# Phenopype: a phenotyping pipeline for Python

**Author:** [Moritz Lürig](https://luerig.net)<br/>
**License:** [MIT](https://opensource.org/licenses/MIT)<br/>

<!-- badges: start -->

| Project status | Windows build | Linux build | OSX build | Coverage | Style | 
|:---:|:---:|:---:|:---:|:---:|:---:|
| [![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](http://www.repostatus.org/badges/latest/active.svg)](http://www.repostatus.org/#active) | [![Build status](https://ci.appveyor.com/api/projects/status/4o27rpjbe8ij2kj3?svg=true)](https://ci.appveyor.com/project/mluerig/phenopype) | [![Build Status](https://travis-ci.org/mluerig/phenopype.svg?branch=master)](https://travis-ci.org/mluerig/phenopype) | *none* | [![Coverage Status](https://coveralls.io/repos/github/mluerig/phenopype/badge.svg?branch=master)](https://coveralls.io/github/mluerig/phenopype?branch=master) | [![Code style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) |
<!-- badges: end -->
<br>

<img src="https://raw.githubusercontent.com/mluerig/phenopype/master/source/phenopype_logo.png">

<div align="justify">

<strong>Phenopype is a high throughput phenotyping pipeline for Python to support biologists in extracting high dimensional phenotypic data from digital images</strong>. The program provides intuitive, high level computer vision functions for image preprocessing, segmentation, and feature extraction. Users can assemble their own function-stacks that can be stored in the  human-readable `yaml`-format along with raw data and results, facilitating high throughput and full data reproducibility. Phenopype can be run from Python or from a Python Integrated Development Environment (IDE), like <i>Spyder</i>. Phenopype is designed to provide robust image analysis workflows that can be implemented with little or no Python experience.<br>

</div>

## Getting started
<ol>
<li><a href="https://mluerig.github.io/phenopype/installation.html">Install Phenopype </a> - via the <i>Python Package Index</i> (PYPI): <code>pip install phenopype</code></li> 
<li><a href="https://mluerig.github.io/phenopype/tutorial_0.html">Run the Tutorials </a> - Tutorial 1 is for Python beginners, otherwise Tutorial 2 is a good starting point </li>
<li><a href="https://mluerig.github.io/phenopype/index.html#examples">Check the Examples</a> - Example 1 delineates a typical computer vision workflow </li>
</ol>

## Documentation
Full documentation can be found here: https://mluerig.github.io/phenopype/
